RawDataElement

Struct RawDataElement 

pub struct RawDataElement {
    pub offset: u64,
    pub header: RecordHeader,
    pub raw_data: Vec<u8>,
    pub byte_order: ByteOrder,
}
unprocessed STDF record data, contains:

  • offset
  • type_code
  • raw_data
  • byte_order

it can be converted back to StdfRecord

use rust_stdf::{RawDataElement, ByteOrder, StdfRecord, RecordHeader, stdf_record_type::REC_FAR};

let rde = RawDataElement {
    offset: 0,
    header: RecordHeader {typ: 0, sub: 10, len: 2},
    raw_data: vec![0u8; 0],
    byte_order: ByteOrder::LittleEndian
};
let rec: StdfRecord = (&rde).into();    // not consume
let rec: StdfRecord = rde.into();       // consume
println!("{:?}", rec);
assert!(rec.is_type(REC_FAR));

Fields

offset: u64

file offset of raw_data in file, after header.len and before raw_data

|-typ-|-sub-|–len–⬇️–raw..data–|

note that the offset is relative to the file position that runs get_rawdata_iter,

it can be treated as file position only if the iteration starts from beginning of the file.

header: RecordHeader

used for identifying StdfRecord types

raw_data: Vec<u8>

field data of current STDF Record

byte_order: ByteOrder

Implementations

Source

impl RawDataElement

pub fn is_type(&self, rec_type: u64) -> bool